@@ -2,6 +2,9 @@ test_that("get_headlines returns a data frame with one column", {
   # adding a small time delay to avoid simultaneous posts to the api
   Sys.sleep(3)
 
+  # Skip when tests are run on CRAN
+  skip_on_cran()
+
   # Get the news
   output_headlines <- get_headlines("ycombinator.com")
 
